aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--Makefile2
-rw-r--r--Sgraph.c (renamed from Spectrogram.c)36
-rw-r--r--Sgraph.h (renamed from Spectrogram.h)18
-rw-r--r--SgraphP.h (renamed from SpectrogramP.h)26
4 files changed, 41 insertions, 41 deletions
diff --git a/Makefile b/Makefile
index ace154b..a576258 100644
--- a/Makefile
+++ b/Makefile
@@ -3,7 +3,7 @@
VERSION=3.0
PROG= spectrogram
-SRCS= spectrogram.c fft.c cms.c aux.c widget.c Spectrogram.c
+SRCS= spectrogram.c fft.c cms.c aux.c widget.c Sgraph.c
LIBS= fftw3 x11 xaw7
BINDIR= /usr/local/bin
diff --git a/SpectrogramP.h b/SgraphP.h
index 8afd418..8213bb9 100644
--- a/SpectrogramP.h
+++ b/SgraphP.h
@@ -15,36 +15,36 @@
* OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/
-#ifndef _SpectrogramP_h
-#define _SpectrogramP_h
+#ifndef _SgraphP_h
+#define _SgraphP_h
-#include "Spectrogram.h"
+#include "Sgraph.h"
/* include superclass private header file */
#include <X11/CoreP.h>
/* define unique representation types not found in <X11/StringDefs.h> */
-#define XtRSpectrogramResource "SpectrogramResource"
+#define XtRSgraphResource "SgraphResource"
typedef struct {
XtPointer extension;
-} SpectrogramClassPart;
+} SgraphClassPart;
-typedef struct _SpectrogramClassRec {
+typedef struct _SgraphClassRec {
CoreClassPart core_class;
- SpectrogramClassPart spectrogram_class;
-} SpectrogramClassRec;
+ SgraphClassPart sgraph_class;
+} SgraphClassRec;
-extern SpectrogramClassRec spectrogramClassRec;
+extern SgraphClassRec sgraphClassRec;
typedef struct {
char *resource;
char *private;
-} SpectrogramPart;
+} SgraphPart;
-typedef struct _SpectrogramRec {
+typedef struct _SgraphRec {
CorePart core;
- SpectrogramPart spectrogram;
-} SpectrogramRec;
+ SgraphPart sgraph;
+} SgraphRec;
#endif
diff --git a/Spectrogram.c b/Sgraph.c
index cc04281..9b13264 100644
--- a/Spectrogram.c
+++ b/Sgraph.c
@@ -18,24 +18,24 @@
#include <X11/IntrinsicP.h>
#include <X11/StringDefs.h>
-#include "SpectrogramP.h"
+#include "SgraphP.h"
/* Class Methods */
static void Initialize(Widget, Widget, ArgList, Cardinal *);
/* Prototypes */
-static Bool Function(SpectrogramWidget, int, int, Bool);
+static Bool Function(SgraphWidget, int, int, Bool);
/* Actions */
static void Action(Widget, XEvent *, String *, Cardinal *);
/* Initialization */
-#define offset(field) XtOffsetOf(SpectrogramRec, spectrogram.field)
+#define offset(field) XtOffsetOf(SgraphRec, sgraph.field)
static XtResource resources[] = {
{
- XtNspectrogramResource, /* name */
- XtCSpectrogramResource, /* class */
- XtRSpectrogramResource, /* type */
+ XtNsgraphResource, /* name */
+ XtCSgraphResource, /* class */
+ XtRSgraphResource, /* type */
sizeof(char *), /* size */
offset(resource), /* offset */
XtRString, /* default_type */
@@ -47,20 +47,20 @@ static XtResource resources[] = {
static XtActionsRec actions[] =
{
{
- "spectrogram", /* name */
+ "sgraph", /* name */
Action /* procedure */
},
};
-static char translations[] = "<Key>:" "spectrogram()\n";
+static char translations[] = "<Key>:" "sgraph()\n";
#define Superclass (&widgetClassRec)
-SpectrogramClassRec spectrogramClassRec = {
+SgraphClassRec sgraphClassRec = {
/* core */
{
(WidgetClass) Superclass, /* superclass */
- "Spectrogram", /* class_name */
- sizeof(SpectrogramRec), /* widget_size */
+ "Sgraph", /* class_name */
+ sizeof(SgraphRec), /* widget_size */
NULL, /* class_initialize */
NULL, /* class_part_initialize */
False, /* class_inited */
@@ -91,13 +91,13 @@ SpectrogramClassRec spectrogramClassRec = {
XtInheritDisplayAccelerator, /* display_accelerator */
NULL, /* extension */
},
- /* spectrogram */
+ /* sgraph */
{
NULL, /* extension */
}
};
-WidgetClass spectrogramWidgetClass = (WidgetClass)&spectrogramClassRec;
+WidgetClass sgraphWidgetClass = (WidgetClass)&sgraphClassRec;
/* Implementation */
@@ -118,9 +118,9 @@ WidgetClass spectrogramWidgetClass = (WidgetClass)&spectrogramClassRec;
static void
Initialize(Widget request, Widget w, ArgList args, Cardinal *num_args)
{
- SpectrogramWidget sw = (SpectrogramWidget)w;
+ SgraphWidget sw = (SgraphWidget)w;
- sw->spectrogram.private = NULL;
+ sw->sgraph.private = NULL;
}
/*
@@ -128,7 +128,7 @@ Initialize(Widget request, Widget w, ArgList args, Cardinal *num_args)
* Function
*
* Parameters:
* sw - spectrogram widget
* x - x coordinate
* y - y coordinate
* force - force action
@@ -141,7 +141,7 @@ Initialize(Widget request, Widget w, ArgList args, Cardinal *num_args)
*/
/* ARGSUSED */
static Bool
-Function(SpectrogramWidget sw, int x, int y, Bool force)
+Function(SgraphWidget sw, int x, int y, Bool force)
{
return (force);
}
@@ -151,7 +151,7 @@ Function(SpectrogramWidget sw, int x, int y, Bool force)
* Action
*
* Parameters:
- * w - spectrogram widget
+ * w - sgraph widget
* event - event that caused this action
* params - parameters
* num_params - number of parameters
@@ -128,7 +128,7 @@ Initialize(Widget request, Widget w, ArgList args, Cardinal *num_args)
*
* Parameters:
- * sw - spectrogram widget
+ * sw - sgraph widget
* x - x coordinate
* y - y coordinate
diff --git a/Spectrogram.h b/Sgraph.h
index a513144..c2366eb 100644
--- a/Spectrogram.h
+++ b/Sgraph.h
@@ -15,14 +15,14 @@
* OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/
-#ifndef _Spectrogram_h
-#define _Spectrogram_h
+#ifndef _Sgraph_h
+#define _Sgraph_h
#include <X11/Intrinsic.h>
/****************************************************************
*
- * Spectrogram widget
+ * Sgraph widget
*
****************************************************************/
@@ -44,14 +44,14 @@
*/
/* define any special resource names here that are not in <X11/StringDefs.h> */
-#define XtNspectrogramResource "spectrogramResource"
-#define XtCSpectrogramResource "SpectrogramResource"
+#define XtNsgraphResource "sgraphResource"
+#define XtCSgraphResource "SgraphResource"
-/* declare specific SpectrogramWidget class and instance datatypes */
-typedef struct _SpectrogramClassRec *SpectrogramWidgetClass;
-typedef struct _SpectrogramRec *SpectrogramWidget;
+/* declare specific SgraphWidget class and instance datatypes */
+typedef struct _SgraphClassRec *SgraphWidgetClass;
+typedef struct _SgraphRec *SgraphWidget;
/* declare the class constant */
-extern WidgetClass spectrogramWidgetClass;
+extern WidgetClass sgraphWidgetClass;
#endif